Mining Endpoints
================

Acquiring Algorithm (MARKET_DATA)
---------------------------------
.. autofunction:: binance.spot.Spot.mining_algo_list

Acquiring CoinName (MARKET_DATA)
--------------------------------
.. autofunction:: binance.spot.Spot.mining_coin_list

Request for Detail Miner List (USER_DATA)
-----------------------------------------
.. autofunction:: binance.spot.Spot.mining_worker

Request for Miner List (USER_DATA)
----------------------------------
.. autofunction:: binance.spot.Spot.mining_worker_list

Revenue List (USER_DATA)
------------------------
.. autofunction:: binance.spot.Spot.mining_earnings_list

Extra Bonus List (USER_DATA)
----------------------------
.. autofunction:: binance.spot.Spot.mining_bonus_list

Statistic List (USER_DATA)
--------------------------
.. autofunction:: binance.spot.Spot.mining_statistics_list

Account List (USER_DATA)
------------------------
.. autofunction:: binance.spot.Spot.mining_account_list

Hashrate Resale Request (USER_DATA)
-----------------------------------
.. autofunction:: binance.spot.Spot.mining_hashrate_resale_request

Cancel hashrate resale configuration(USER_DATA)
-----------------------------------------------
.. autofunction:: binance.spot.Spot.mining_hashrate_resale_cancellation

Hashrate Resale List (USER_DATA)
--------------------------------
.. autofunction:: binance.spot.Spot.mining_hashrate_resale_list

Hashrate Resale Detail (USER_DATA)
----------------------------------
.. autofunction:: binance.spot.Spot.mining_hashrate_resale_details

Mining Account Earning (USER_DATA)
----------------------------------
.. autofunction:: binance.spot.Spot.mining_account_earning
